@@ -60,6 +60,9 @@ uint32_t buffer_get_int(Buffer *buffer);
 uint64_t get_u64le(const void *vp);
 int buffer_get_int64_le_ret(uint64_t *ret, Buffer *buffer);
 uint64_t buffer_get_int64_le(Buffer *buffer);
+uint64_t get_u64(const void *vp);
+int buffer_get_int64_ret(uint64_t *ret, Buffer *buffer);
+uint64_t buffer_get_int64(Buffer *buffer);
 uint16_t get_u16le(const void *vp);
 int buffer_get_short_le_ret(uint16_t *ret, Buffer *buffer);
 uint16_t buffer_get_short_le(Buffer *buffer);
